Cscipy
===

#### How to install?
Compatible with Python 2 and 3. 
On Windows, Visual Studio 2015 Build Tools is also required.

```bash
pip install Cython
```

#### How to recompile to use in IDE?
- `rm cscipy/*.cpp; python setup.py build_ext --inplace`

#### Licence
- MIT